==> groupoffice-com-4.0.97.tar.gz: groupoffice-com-4.0.97/modules/users/language/nl.php <==
<?php


$l['name'] = 'Gebruikers';
$l['description'] = 'Beheren van de gebruikers';
$l['deletePrimaryAdmin'] = 'U kunt de primaire Administrator niet verwijderen';
$l['deleteYourself'] = 'U kunt zichzelf niet verwijderen';
$lang['link_type'][8]=$us_user = 'Gebruiker';
$l['error_username']='Er staan ongeldige tekens in de gebruikersnaam';
$l['error_username_exists']='Sorry, die gebruikersnaam bestaat al';
$l['error_email_exists']='Sorry, dat e-mail adres staat hier al geregistreerd.';
$l['error_match_pass']='De wachtwoorden kwamen niet overeen';
$l['error_email']='U heeft een ongeldig e-mail adres ingevoerd';
$l['error_user']='Gebruiker kon niet worden aangemaakt';
$l['imported']='%s gebruikers geïmporteerd';
$l['failed']='Mislukt';
$l['incorrectFormat']='Bestand was niet in het jusite CSV formaat';
$l['register_email_subject']='Uw {product_name} account gegevens';
$l['register_email_body']='Er is een {product_name} account voor u aangemaakt op {url}
Uw inloggegevens zijn:
Gebruikersnaam: {username};
Wachtwoord: {password}';$l["cmdCheckColumnRead"]= 'Lezen';
$l["cmdCheckColumnWrite"]= 'Schrijven';
$l["cmdHeaderColumnName"]= 'Module naam';
$l["cmdHeaderGridUserHasAccess"]= 'Gebruiker heeft toegang tot';
$l["userIsMemberOf"]= 'Gebruiker is lid van';
$l["userVisibleTo"]= 'Gebruiker is zichtbaar aan';
$l["cmdPanelPersonal"]= 'Persoonlijk';
$l["cmdPanelPassword"]= 'Wachtwoord';
$l["cmdPanelCompany"]= 'Bedrijf';
$l["cmdPanelPermissions"]= 'Permissies';
$l["cmdPanelLogin"]= 'Login';
$l["cmdPanelLookFeel"]= 'Uiterlijk';
$l["cmdPanelSettings"]= 'Instellingen';
$l["cmdPanelEnabledMail"]= 'Email voor nieuwe geactiveerde gebruikers';
$l["cmdPanelDisabledMail"]= 'Email voor nieuwe gedeactiveerde gebruikers';
$l["cmdFieldSetPersonal"]= 'Persoonlijk';	;
$l["cmdUserWindowTitle"]= 'Gebruiker aanpassen';
$l["cmdNotificationWindowTitle"]= 'Gebruiker uitnodigings mail aanpassen';
$l["cmdMaskSaving"]= 'Opslaan';
$l["cmdFormLabelSubject"]= 'Onderwerp';
$l["cmdFormLabelUsername"]= 'Gebruikersnaam';
$l["cmdFormLabelName"]= 'Naam';
$l["cmdFormLabelPassword"]= 'Wachtwoord';
$l["cmdFormLabelConfirm"]= 'Bevestigen';
$l["cmdBoxLabelEnabled"]= 'Geactiveerd';
$l["cmdFormLabelHomepage"]= 'Startpagina';
$l["cmdFormLabelRegistrationTime"]= 'Registratie tijd';
$l["cmdFormLabelLastLogin"]= 'Laatste Login';
$l["cmdFormLabelTotalLogins"]= 'Totaal aantal Logins';
$l["numberOfLogins"]= 'Aantal logins';
$l["cmdFormLabelTheme"]= 'Thema';
$l["cmdFormLabelStartModule"]= 'Start in module';
$l["cmdFormLabelMaximunRows"]= 'Maximaal aantal rijen in een lijst';
$l["cmdFormLabelSortNamesBy"]= 'Sorteer namen op';
$l["cmdFormLabelLanguage"]= 'Taal';
$l["cmdFormLabelTimezone"]= 'Tijdzone';
$l["cmdFormLabelAdjustDaylight"]= 'Pas tijd automatisch aan zomertijd aan';
$l["cmdFormLabelDateFormat"]= 'Datum formaat';
$l["cmdFormLabelDateSeperator"]= 'Datum scheidingsteken';
$l["timeFormat"]= 'Tijd formaat';
$l["cmdFormLabelFirstWeekday"]= 'Eerste dag van de week';
$l["cmdFormLabelThousandSeperator"]= 'Duizendtal scheidingsteken';
$l["cmdFormLabelDecimalSeperator"]= 'Decimaal scheidingsteken';
$l["cmdFormLabelCurrency"]= 'Valuta';
$l["account"]= 'Account';
$l["confirmPassword"]= 'Wachtwoord bevestigen';
$l["companyProfile"]= 'Bedrijfsprofiel';
$l["loginInfo"]= 'Login informatie';
$l["changePassword"]= 'Wachtwoord veranderen';
$l["currentPassword"]= 'Huidig wachtwoord';
$l["newPassword"]= 'Nieuw wachtwoord';
$l["confirmPassword"]= 'Wachtwoord bevestigen';
$l["moduleAccess"]= 'Module toegang';
$l["groupMembership"]= 'Groepslidmaatschap';
$l["personalProfile"]= 'Persoonlijk profiel';
$l["settings"]= 'Persoonlijke instellingen';
$l["dmy"]= 'Dag-Maand-Jaar';
$l["mdy"]= 'Maand-Dag-Jaar';
$l["jmd"]= 'Jaar-Maand-Dag';
$l["fullhourformat"]= '24 uurs formaat';
$l["halfhourformat"]= '12 uurs formaat';
$l["sunday"]= 'Zondag';
$l["monday"]= 'Maandag';
$l["regionalSettings"]= 'Regionale instellingen';
$l["userSettings"]= 'Gebruikers instellingen';
$l["maxUsersReached"]='Het maximaal aantal gebruikers is bereikt. Neem contact op met uw provider om het maximaal aantal gebruikers uit te breiden.';
$l["group"]='Groep';
$l["profile"]='Profiel';
$l["muteSound"]='Demp alle geluiden';
$l["mailReminders"]='Email herinneringen';
$l["downloadSampleCSV"]='Download voorbeeld CSV';
$l["importText"]='U kunt gebruikers importeren met een CSV bestand. Om te zien hoe dit bestand eruit moet zien kunt u het voorbeeldbestand downloaden.<br />De eerste regel moet de kollomnamen bevatten en de volgende velden zijn vereist voor elke gebruiker:<br /><br />username, password, first_name, last_name, email';
$l["useModule"]= 'Gebruiken';
$l["manageModule"]= 'Beheren';
$l["numberFormat"]='Nummerformaat';
$l["importExport"]='Import / Export';
$l["listSeparator"]='Lijstscheidingsteken';
$l["textSeparator"]='Tekstschedingsteken';
$l["deleteWarning"]='WAARSCHUWING!!! Alle gegevens van de gebruiker inclusief adresboeken, agenda\'s en projecten worden verwijderd!';
$l["lastName"]= 'Achternaam';
$l["firstName"]= 'Voornaam';
$l["sendInvitation"]='Verstuur uitnodiging';
$l["contactInfo"]='Contact information';
$l["popupNotification"]='Toon een popup scherm wanneer een herinnering actief wordt of e-mail arriveert';
$l["muteNewMailSound"]='Demp geluid bij inkomende mail';
$l["muteReminderSound"]='Demp geluid bij herinneringen';
$l["showSmilies"]='Toon smilies';

$l['openContact']='Open contactpersoon';

$l['showProUsers']='Toon pro grebruikers';

==> groupoffice-com-4.1.7.tar.gz: groupoffice-com-4.1.7/modules/users/language/nl.php <==
<?php


$l['name'] = 'Gebruikers';
$l['description'] = 'Beheren van de gebruikers';
$l['deletePrimaryAdmin'] = 'U kunt de primaire Administrator niet verwijderen';
$l['deleteYourself'] = 'U kunt zichzelf niet verwijderen';

$l['error_username']='Er staan ongeldige tekens in de gebruikersnaam';
$l['error_username_exists']='Sorry, die gebruikersnaam bestaat al';
$l['error_email_exists']='Sorry, dat e-mail adres staat hier al geregistreerd.';
$l['error_match_pass']='De wachtwoorden kwamen niet overeen';
$l['error_email']='U heeft een ongeldig e-mail adres ingevoerd';
$l['error_user']='Gebruiker kon niet worden aangemaakt';
$l['imported']='%s gebruikers geïmporteerd';
$l['failed']='Mislukt';
$l['incorrectFormat']='Bestand was niet in het jusite CSV formaat';
$l['register_email_subject']='Uw {product_name} account gegevens';
$l['register_email_body']='Er is een {product_name} account voor u aangemaakt op {url}
Uw inloggegevens zijn:
Gebruikersnaam: {username};
Wachtwoord: {password}';
$l["cmdCheckColumnRead"]= 'Lezen';
$l["cmdCheckColumnWrite"]= 'Schrijven';
$l["cmdHeaderColumnName"]= 'Module naam';
$l["cmdHeaderGridUserHasAccess"]= 'Gebruiker heeft toegang tot';
$l["userIsMemberOf"]= 'Gebruiker is lid van';
$l["userVisibleTo"]= 'Gebruiker is zichtbaar aan';
$l["cmdPanelPersonal"]= 'Persoonlijk';
$l["cmdPanelPassword"]= 'Wachtwoord';
$l["cmdPanelCompany"]= 'Bedrijf';
$l["cmdPanelPermissions"]= 'Permissies';
$l["cmdPanelLogin"]= 'Login';
$l["cmdPanelLookFeel"]= 'Uiterlijk';
$l["cmdPanelSettings"]= 'Instellingen';
$l["cmdPanelEnabledMail"]= 'Email voor nieuwe geactiveerde gebruikers';
$l["cmdPanelDisabledMail"]= 'Email voor nieuwe gedeactiveerde gebruikers';
$l["cmdFieldSetPersonal"]= 'Persoonlijk';	;
$l["cmdUserWindowTitle"]= 'Gebruiker aanpassen';
$l["cmdNotificationWindowTitle"]= 'Gebruiker uitnodigings mail aanpassen';
$l["cmdMaskSaving"]= 'Opslaan';
$l["cmdFormLabelSubject"]= 'Onderwerp';
$l["cmdFormLabelUsername"]= 'Gebruikersnaam';
$l["cmdFormLabelName"]= 'Naam';
$l["cmdFormLabelPassword"]= 'Wachtwoord';
$l["cmdFormLabelConfirm"]= 'Bevestigen';
$l["cmdBoxLabelEnabled"]= 'Geactiveerd';
$l["cmdFormLabelHomepage"]= 'Startpagina';
$l["cmdFormLabelRegistrationTime"]= 'Registratie tijd';
$l["cmdFormLabelLastLogin"]= 'Laatste Login';
$l["cmdFormLabelTotalLogins"]= 'Totaal aantal Logins';
$l["numberOfLogins"]= 'Aantal logins';
$l["cmdFormLabelTheme"]= 'Thema';
$l["cmdFormLabelStartModule"]= 'Start in module';
$l["cmdFormLabelMaximunRows"]= 'Maximaal aantal rijen in een lijst';
$l["cmdFormLabelSortNamesBy"]= 'Sorteer namen op';
$l["cmdFormLabelLanguage"]= 'Taal';
$l["cmdFormLabelTimezone"]= 'Tijdzone';
$l["cmdFormLabelAdjustDaylight"]= 'Pas tijd automatisch aan zomertijd aan';
$l["cmdFormLabelDateFormat"]= 'Datum formaat';
$l["cmdFormLabelDateSeperator"]= 'Datum scheidingsteken';
$l["timeFormat"]= 'Tijd formaat';
$l["cmdFormLabelFirstWeekday"]= 'Eerste dag van de week';
$l["cmdFormLabelThousandSeperator"]= 'Duizendtal scheidingsteken';
$l["cmdFormLabelDecimalSeperator"]= 'Decimaal scheidingsteken';
$l["cmdFormLabelCurrency"]= 'Valuta';
$l["account"]= 'Account';
$l["companyProfile"]= 'Bedrijfsprofiel';
$l["loginInfo"]= 'Login informatie';
$l["changePassword"]= 'Wachtwoord veranderen';
$l["currentPassword"]= 'Huidig wachtwoord';
$l["newPassword"]= 'Nieuw wachtwoord';
$l["confirmPassword"]= 'Wachtwoord bevestigen';
$l["moduleAccess"]= 'Module toegang';
$l["groupMembership"]= 'Groepslidmaatschap';
$l["personalProfile"]= 'Persoonlijk profiel';
$l["settings"]= 'Persoonlijke instellingen';
$l["dmy"]= 'Dag-Maand-Jaar';
$l["mdy"]= 'Maand-Dag-Jaar';
$l["jmd"]= 'Jaar-Maand-Dag';
$l["fullhourformat"]= '24 uurs formaat';
$l["halfhourformat"]= '12 uurs formaat';
$l["sunday"]= 'Zondag';
$l["monday"]= 'Maandag';
$l["regionalSettings"]= 'Regionale instellingen';
$l["userSettings"]= 'Gebruikers instellingen';
$l["maxUsersReached"]='Het maximaal aantal gebruikers is bereikt. Neem contact op met uw provider om het maximaal aantal gebruikers uit te breiden.';
$l["group"]='Groep';
$l["profile"]='Profiel';
$l["muteSound"]='Demp alle geluiden';
$l["mailReminders"]='Email herinneringen';
$l["downloadSampleCSV"]='Download voorbeeld CSV';
$l["importText"]='U kunt gebruikers importeren met een CSV bestand. Om te zien hoe dit bestand eruit moet zien kunt u het voorbeeldbestand downloaden.<br />De eerste regel moet de kollomnamen bevatten en de volgende velden zijn vereist voor elke gebruiker:<br /><br />username, password, first_name, last_name, email';
$l["useModule"]= 'Gebruiken';
$l["manageModule"]= 'Beheren';
$l["numberFormat"]='Nummerformaat';
$l["importExport"]='Import / Export';
$l["listSeparator"]='Lijstscheidingsteken';
$l["textSeparator"]='Tekstschedingsteken';
$l["deleteWarning"]='WAARSCHUWING!!! Alle gegevens van de gebruiker inclusief adresboeken, agenda\'s en projecten worden verwijderd!';
$l["lastName"]= 'Achternaam';
$l["firstName"]= 'Voornaam';
$l["sendInvitation"]='Verstuur uitnodiging';
$l["contactInfo"]='Contact information';
$l["popupNotification"]='Toon een popup scherm wanneer een herinnering actief wordt of e-mail arriveert';
$l["muteNewMailSound"]='Demp geluid bij inkomende mail';
$l["muteReminderSound"]='Demp geluid bij herinneringen';
$l["showSmilies"]='Toon smilies';

$l['openContact']='Open contactpersoon';

$l['showProUsers']='Toon pro grebruikers';


$l['max_users_reached']='Het maximale aantal gebruikers is bereikt voor dit systeem.';
$l['dashdmy']='Dag-Maand-Jaar';
$l['slashmdy']='Maand/Dag/Jaar';
$l['dotdmy']='Dag.Maand.Jaar';
$l['slashdmy']='Dag/Maand/Jaar';
$l['generatePassword']='Genereer wachtwoord';
$l['generatedPasswordIs']='Het gegenereerde wachtwoord is';
$l['updateExistingOnImport']='Werk bestaande gebruikers bij op basis van username';
